diff scripts/general/interpn.m @ 8116:6c69f5cda32b

For for extrapval in interpn
author Kris Thielemans
date Thu, 18 Sep 2008 10:46:24 -0400
parents 4fbaba9abec1
children fa78cb8d8a5c
line wrap: on
line diff
--- a/scripts/general/interpn.m	Thu Sep 18 10:42:54 2008 -0400
+++ b/scripts/general/interpn.m	Thu Sep 18 10:46:24 2008 -0400
@@ -55,9 +55,9 @@
 ##
 ## The default method is 'linear'.
 ##
 ## If @var{extrap} is the string 'extrap', then extrapolate values beyond
 ## the endpoints.  If @var{extrap} is a number, replace values beyond the
 ## endpoints with that number.  If @var{extrap} is missing, assume NA.
 ## @seealso{interp1, interp2, spline, ndgrid}
 ## @end deftypefn
 
@@ -79,6 +79,7 @@
       error ("extrapal is expected to be a numeric scalar");
     endif
     method = varargin{end - 1};
+    extrapval = varargin{end};
     nargs = nargs - 2;
   endif
@@ -55,9 +55,9 @@
 ## The default method is 'linear'.
 ##
-## If @var{extrap} is the string 'extrap', then extrapolate values beyond
-## the endpoints.  If @var{extrap} is a number, replace values beyond the
-## endpoints with that number.  If @var{extrap} is missing, assume NA.
+## If @var{extrapval} is the scalar value, use it to replace the values
+## beyond the endpoints with that number. If @var{extrapval} is missing,
+## assume NA.
 ## @seealso{interp1, interp2, spline, ndgrid}
 ## @end deftypefn